yakumo.neutron.v2.network

Package yakumo :: Package neutron :: Package v2 :: Module network |
[hide private]
[frames] | no frames]

# Module network

source code

Resource class and its manager for networks in Networking V2 API

Classes | [hide private]
| Resource Resource class for networks in Networking V2 API
| Manager Manager class for networks in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('subnets', 'subnets', mapper.List(mapper.Reso
      urce('neutron.subnet'))), ('project', 'tenant_id', mapper.Resource('pr
      oject')), ('is_shared', 'shared', mapper.Noop), ('is_enabled', 'admin_
      state_up', mapper.Noop), ('is_external', 'router:external', mapper.Noo
      p), ('is_secured', 'port_security_enabled', mapper.Noop), ('segments',
       'segments', mapper.Noop), ('provider_physical_network', 'provider:phy
      sical_network', mapper.Noop), ('provider_network_type', 'provider:netw
      ...